@@ -22,12 +22,11 @@ class ACLNoteData : public ACLData<NotePairs::Entry *>
 
 public:
     ACLNoteData();
-    virtual ~ACLNoteData();
-    virtual bool match(NotePairs::Entry *);
-    virtual SBufList dump() const;
-    virtual void parse();
-    virtual bool empty() const;
-    virtual ACLData<NotePairs::Entry *> *clone() const;
+    ~ACLNoteData() override;
+    bool match(NotePairs::Entry *) override;
+    SBufList dump() const override;
+    void parse() override;
+    bool empty() const override;
 
 private:
     SBuf name;                   ///< Note name to check. It is always set
