@@ -25,23 +25,16 @@ class Scheme : public Auth::Scheme
 public:
     static Auth::Scheme::Pointer GetInstance();
     Scheme() {};
-    virtual ~Scheme() {};
+    ~Scheme() override {};
 
     /* per scheme */
-    virtual char const *type() const;
-    virtual void shutdownCleanup();
-    virtual Auth::SchemeConfig *createConfig();
+    char const *type() const override;
+    void shutdownCleanup() override;
+    Auth::SchemeConfig *createConfig() override;
 
     /* Not implemented */
     Scheme (Scheme const &);
     Scheme &operator=(Scheme const &);
-
-private:
-    /**
-     * Main instance of this authentication Scheme.
-     * NULL when the scheme is not being used.
-     */
-    static Auth::Scheme::Pointer _instance;
 };
 
 } // namespace Ntlm
